<?php

namespace Roots\Sage\Assets;

/**
 * Scripts and stylesheets
 *
 * Enqueue stylesheets in the following order:
 * 1. /theme/dist/styles/main.css
 *
 * Enqueue scripts in the following order:
 * 1. /theme/dist/scripts/modernizr.js
 * 2. /theme/dist/scripts/main.js
 */

class JsonManifest {
  private $manifest;

  public function __construct($manifest_path) {
    if (file_exists($manifest_path)) {

      $this->manifest = json_decode($this->getFile($manifest_path), true);
    } else {
      $this->manifest = [];
    }
  }

  public function get() {
    return $this->manifest;
  }

  public function getPath($key = '', $default = null) {
    $collection = $this->manifest;
    if (is_null($key)) {
      return $collection;
    }
    if (isset($collection[$key])) {
      return $collection[$key];
    }
    foreach (explode('.', $key) as $segment) {
      if (!isset($collection[$segment])) {
        return $default;
      } else {
        $collection = $collection[$segment];
      }
    }
    return $collection;
  }
  public static function getFile($path)
    {
        global $wp_filesystem;
        include_once ABSPATH . 'wp-admin/includes/file.php';
        // If for some reason the include doesn't work as expected just return false.
        if (!function_exists('WP_Filesystem')) {
            return false;
        } else {
            // If WP_Filesystem exist
            if (WP_Filesystem()) {
                $wp_filesystem->method = 'direct';
                $file_content = $wp_filesystem->get_contents($path);
                return $file_content;
            } else {
                return false;
            }
        }
    }
}

function asset_path($filename) {
  $dist_path = get_template_directory_uri() . DIST_DIR;
  $directory = dirname($filename) . '/';
  $file = basename($filename);
  static $manifest;

  if (empty($manifest)) {
    $manifest_path = get_template_directory() . DIST_DIR . 'assets.json';
    $manifest = new JsonManifest($manifest_path);
  }

  if (array_key_exists($file, $manifest->get())) {
    return $dist_path . $directory . $manifest->get()[$file];
  } else {
    return $dist_path . $directory . $file;
  }
}

function assets() {
  wp_enqueue_style('sage_css', asset_path('styles/main.css'), false, null);
  wp_enqueue_style('google_fonts', 'http://fonts.googleapis.com/css?family=Open+Sans:400,600');
  wp_enqueue_style('google_fonts_additional', 'http://fonts.googleapis.com/css?family=PT+Sans:400,600');

  wp_add_inline_style('sage_css', get_option('color_overrides'));

  wp_enqueue_script('google_map_js', 'http://maps.googleapis.com/maps/api/js?region=ru&language=ru-RU&v=3.exp&sensor=false');
  wp_enqueue_script('sage_js', asset_path('scripts/main.js'), ['jquery'], null, true);
}
add_action('wp_enqueue_scripts', __NAMESPACE__ . '\\assets', 100);